@@ -184,11 +184,11 @@ static void printUsage(void) {
             "Options:\n"
             "    -u  print usage information\n"
             "    -h  print usage and help information\n"
-            "    -ht print table-specific usage information\n"
+            "   -ht  print table-specific usage information\n"
             "    -r  dump Macintosh resource map\n"
             "    -n  dump glyph id/name mapping (also see '-m' below)\n"
-            "    -nc dump glyph id/name mapping, one per line (also see '-m' below)\n"
-            "    -ngid Suppress terminal gid on glyph names from TTF fonts.\n"
+            "   -nc  dump glyph id/name mapping, one per line (also see '-m' below)\n"
+            " -ngid  Suppress terminal gid on glyph names from TTF fonts.\n"
             "    -T  list table-directory in sfnt table\n"
             "    -F  list features in GPOS,GSUB tables\n"
             "    -G  proof glyph synopsis\n"
@@ -196,7 +196,7 @@ static void printUsage(void) {
             "    -V  proof glyphs in Vertical writing mode (same as -p6 below)\n"
             "    -m  map glyph names into Adobe 'friendly' names, not AGL/Unicode names\n"
             "    -d  suppress header info from proof\n"
-            "    -br proof glyph synopsis one per page\n"
+            "   -br  proof glyph synopsis one per page\n"
 #if AUTOSPOOL
             "    -l  leave proofing output files; do not spool them to printer\n"
             "    -O  proof data to 'stdout' (e.g., for sending to printer or saving to some file)\n"
@@ -217,9 +217,10 @@ static void printUsage(void) {
 #if AUTOSCRIPT
             "    -X  execute a series of complete command-lines from <scriptfile> [default: OTFproof.scr ]\n"
 #endif
-            "Note: Proof options write a PostScript file to standard output, and must be redirected to a file. \n"
-            "Example: 'spot -P kern test.otf > kern.ps'   This file can then be converted to PDF with Distiller, or\n"
-            "downloaded to a printer.\n"
+            "\n"
+            "Note: Proof options write a PostScript file to standard output, and must be redirected to a file.\n"
+            "Example: 'spot -P kern test.otf > kern.ps'\n"
+            "This file can then be converted to PDF with Distiller, or downloaded to a printer.\n"
             "\n"
             "Version:\n"
             "    %s\n",
@@ -241,49 +242,52 @@ static void showHelp(void) {
     printUsage();
     sfntUsage();
     fprintf(OUTPUTBUFF,
-            "Notes:\n"
-            "    This program dumps sfnt data from plain files or Macintosh\n"
-            "resource files. In the latter case, when there are 2 or more sfnt\n"
-            "resources, or in the absence of the -i option, the resource map\n"
-            "is dumped as a list of resource types and ids. The program may\n"
-            "then be rerun with an argument to the -i option specifying a\n"
-            "comma-separated sfnt id list of the sfnt resources to be dumped\n"
-            "or the argument 'all' which dumps all sfnt resources.\n"
-            "    All the multiple sfnts within an OpenType Collection (TTC)\n"
-            "will be dumped by default but may be selectively dumped via TTC\n"
-            "directory offsets specified with the -o option, e.g.\n"
-            "-o0x14,0x170. Use the -tttcf option to view all the TTC\n"
-            "directory offsets available.\n"
-            "    The argument to the -t option specifies a list of tables to\n"
-            "be dumped. Tables are selected by a comma-separated list of\n"
-            "table tags, e.g. cmap,MMVR,fdsc. An optional dump level may be\n"
-            "specified by appending '=' followed by the level to a tag,\n"
-            "e.g. cmap=2. Higher levels print successively more information\n"
-            "up to a maximum of 4 (the default) although all 4 levels are not\n"
-            "supported by all tables. Level 1 always prints the table tag and\n"
-            "file offset. When a level is specified its value becomes the\n"
-            "default for the remaining tables in the list unless a new level\n"
-            "is specified, e.g. cmap=2,MMVR,HFMX,fdsc=1 dumps the cmap, MMVR,\n"
-            "and HFMX tables at level 2 and the fdsc table at level 1. If a\n"
-            "level is given as 'x', e.g. cmap=x the table is dumped in\n"
-            "hexadecimal format. If an unsupported table tag is specified the\n"
-            "table is dumped in hexadecimal format regardless of whether a\n"
-            "level of 'x' is specified.\n");
+        "Notes:\n"
+        "\n"
+        "This program dumps sfnt data from plain files or Macintosh resource\n"
+        "files.\n"
+        "In the latter case, when there are 2 or more sfnt resources, or in\n"
+        "the absence of the -i option, the resource map is dumped as a list of\n"
+        "resource types and ids. The program may then be rerun with an argument\n"
+        "to the -i option specifying a comma-separated sfnt id list of the sfnt\n"
+        "resources to be dumped or the argument 'all' which dumps all sfnt\n"
+        "resources.\n"
+        "\n"
+        "All the multiple sfnts within an OpenType Collection (TTC) will be\n"
+        "dumped by default but may be selectively dumped via TTC directory\n"
+        "offsets specified with the -o option, e.g. -o0x14,0x170. Use the\n"
+        "-tttcf option to view all the TTC directory offsets available.\n"
+        "\n"
+        "The argument to the -t option specifies a list of tables to be dumped.\n"
+        "Tables are selected by a comma-separated list of table tags, e.g.\n"
+        "cmap,MMVR,fdsc. An optional dump level may be specified by appending\n"
+        "'=' followed by the level to a tag, e.g. cmap=2. Higher levels print\n"
+        "successively more information up to a maximum of 4 (the default)\n"
+        "although all 4 levels are not supported by all tables. Level 1 always\n"
+        "prints the table tag and file offset. When a level is specified its\n"
+        "value becomes the default for the remaining tables in the list unless\n"
+        "a new level is specified, e.g. cmap=2,MMVR,HFMX,fdsc=1 dumps the cmap,\n"
+        "MMVR, and HFMX tables at level 2 and the fdsc table at level 1. If a\n"
+        "level is given as 'x', e.g. cmap=x the table is dumped in hexadecimal\n"
+        "format. If an unsupported table tag is specified the table is dumped\n"
+        "in hexadecimal format regardless of whether a level of 'x' is\n"
+        "specified.\n\n");
     fprintf(OUTPUTBUFF,
-            "    The -n option dumps glyph id to glyph name mapping for all\n"
-            "glyphs in the font. Naming information is extracted from post\n"
-            "format 1.0, 2.0, or 2.5 tables, or if they are not available,\n"
-            "the MS UGL cmap. In the event that none of these is available\n"
-            "the glyph name is simply printed as @ followed by the decimal\n"
-            "glyph id in decimal.\n"
-            "    The special tag 'sfnt' dumps the sfnt directory which lists\n"
-            "all the table present in the sfnt. The special tag 'uset' sets\n"
-            "the dump level on all unset tables in the font allowing tables\n"
-            "to be dumped without explicitly naming them, e.g. -tuset will\n"
-            "dump all tables at the default level 4. If this produces too\n"
-            "much information you can disable dumping of selected tables by\n"
-            "setting their dump level to 0, e.g. -tuset,glyf=0,hdmx.\n"
-            "    The -ht option provides additional table-specific help.\n");
+        "The -n option dumps glyph id to glyph name mapping for all glyphs in\n"
+        "the font. Naming information is extracted from post format 1.0, 2.0,\n"
+        "or 2.5 tables, or if they are not available, the MS UGL cmap. In the\n"
+        "event that none of these is available the glyph name is simply printed\n"
+        "as @ followed by the decimal glyph id in decimal.\n"
+        "\n"
+        "The special tag 'sfnt' dumps the sfnt directory which lists all the\n"
+        "tables present in the sfnt. The special tag 'uset' sets the dump level\n"
+        "on all unset tables in the font allowing tables to be dumped without\n"
+        "explicitly naming them, e.g. -tuset will dump all tables at the\n"
+        "default level 4. If this produces too much information you can disable\n"
+        "dumping of selected tables by setting their dump level to 0, e.g.\n"
+        "-tuset,glyf=0,hdmx.\n"
+        "\n"
+        "The -ht option provides additional table-specific help.\n");
 
     quit(0);
 }
